
# lospec2aseprite

Import a lospec palette into aseprite, personal use, feel free to read and modify this for your own needs

## How to use

`# lospec2aseprite [URL]`

It will automaticaly create an extension per author and add the palette. If several palettes for an author are added, it automatically update the extension. You have to restart Aseprite between adds.

## How to install

### Via `pip`

`pip install lospec2aseprite`

### Via the sources

* `git clone https://github.com/Konosprod/lospec2aseprite.git`
* `cd lospec2aseprite`
* `poetry install`

